==> openesb-standalone-container-3.0.1-sources.jar: net/openesb/standalone/naming/jaxb/Property.java <==
//
// Ce fichier a été généré par l'implémentation de référence JavaTM Architecture for XML Binding (JAXB), v2.2.7 
// Voir <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
// Toute modification apportée à ce fichier sera perdue lors de la recompilation du schéma source. 
// Généré le : 2015.02.13 à 03:35:29 PM CET 
//


package net.openesb.standalone.naming.jaxb;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlElementRefs;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour propertyComplexType complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="propertyComplexType">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence maxOccurs="unbounded" minOccurs="0">
 *         &lt;element name="name" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="value" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="description" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "propertyComplexType", propOrder = {
    "nameAndValueAndDescription"
})
public class Property {

    @XmlElementRefs({
        @XmlElementRef(name = "name", namespace = "http://www.open-esb.net/standalone/jndi/", type = JAXBElement.class, required = false),
        @XmlElementRef(name = "description", namespace = "http://www.open-esb.net/standalone/jndi/", type = JAXBElement.class, required = false),
        @XmlElementRef(name = "value", namespace = "http://www.open-esb.net/standalone/jndi/", type = JAXBElement.class, required = false)
    })
    protected List<JAXBElement<String>> nameAndValueAndDescription;

    /**
     * Gets the value of the nameAndValueAndDescription property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the nameAndValueAndDescription property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNameAndValueAndDescription().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link JAXBElement }{@code <}{@link String }{@code >}
     * {@link JAXBElement }{@code <}{@link String }{@code >}
     * {@link JAXBElement }{@code <}{@link String }{@code >}
     * 
     * 
     */
    public List<JAXBElement<String>> getNameAndValueAndDescription() {
        if (nameAndValueAndDescription == null) {
            nameAndValueAndDescription = new ArrayList<JAXBElement<String>>();
        }
        return this.nameAndValueAndDescription;
    }

}

==> openesb-standalone-container-3.0.2-sources.jar: net/openesb/standalone/naming/jaxb/Property.java <==
//
// Ce fichier a été généré par l'implémentation de référence JavaTM Architecture for XML Binding (JAXB), v2.2.7 
// Voir <a href="http://java.sun.com/xml/jaxb">http://java.sun.com/xml/jaxb</a> 
// Toute modification apportée à ce fichier sera perdue lors de la recompilation du schéma source. 
// Généré le : 2015.03.17 à 10:47:28 PM CET 
//


package net.openesb.standalone.naming.jaxb;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlElementRefs;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour propertyComplexType complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="propertyComplexType">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence maxOccurs="unbounded" minOccurs="0">
 *         &lt;element name="name" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="value" type="{http://www.w3.org/2001/XMLSchema}string"/>
 *         &lt;element name="description" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "propertyComplexType", propOrder = {
    "nameAndValueAndDescription"
})
public class Property {

    @XmlElementRefs({
        @XmlElementRef(name = "value", namespace = "http://www.open-esb.net/standalone/jndi/", type = JAXBElement.class, required = false),
        @XmlElementRef(name = "name", namespace = "http://www.open-esb.net/standalone/jndi/", type = JAXBElement.class, required = false),
        @XmlElementRef(name = "description", namespace = "http://www.open-esb.net/standalone/jndi/", type = JAXBElement.class, required = false)
    })
    protected List<JAXBElement<String>> nameAndValueAndDescription;

    /**
     * Gets the value of the nameAndValueAndDescription property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the nameAndValueAndDescription property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getNameAndValueAndDescription().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link JAXBElement }{@code <}{@link String }{@code >}
     * {@link JAXBElement }{@code <}{@link String }{@code >}
     * {@link JAXBElement }{@code <}{@link String }{@code >}
     * 
     * 
     */
    public List<JAXBElement<String>> getNameAndValueAndDescription() {
        if (nameAndValueAndDescription == null) {
            nameAndValueAndDescription = new ArrayList<JAXBElement<String>>();
        }
        return this.nameAndValueAndDescription;
    }

}
